# HaniLab

HaniLab is a computer vision tool that automates manual labeling by utilizing open-dictionary object detection. It helps AI engineers reduce the manual efforts required to build computer vision models by more than 90%.

## Installation

```bash
pip install hanilab
